module TokenValidate
  extend ActiveSupport::Concern
  ACCESS_TOEKN_EXPIRE_TIME = 7200
    
  def validate_token(app_name, token)
    !! (token == get_token(app_name))
  end

  def token_ttl(app_name)
    $redis.ttl(tkey(app_name))
  end

  def generate_token(sequence_number, app_name)
    sequence_number = sequence_number.to_f
    
    if sequence_number > get_sequence_number(app_name).to_f
      $redis.set(sequence_number_key(app_name), sequence_number, ex: ACCESS_TOEKN_EXPIRE_TIME)
      
      token = SecureRandom.hex(32)
      $redis.set(tkey(app_name), token, ex: ACCESS_TOEKN_EXPIRE_TIME)
      [sequence_number , token]
    else
      [get_sequence_number(app_name).to_f, get_token(app_name)]
    end
    
    
  end

  private

  def tkey(app_name)
    "push:api:#{app_name}:access_token"
  end
  
  def sequence_number_key(app_name)
    "push:api:#{app_name}:sequence_number"
  end

  def get_token(app_name)
    $redis.get(tkey(app_name))
  end

  def get_sequence_number(app_name)
    $redis.get(sequence_number_key(app_name))
  end

end